==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/events/MapAdminEventEntityDelegate.java <==
package org.keycloak.models.map.events;
public class MapAdminEventEntityDelegate implements org.keycloak.models.map.events.MapAdminEventEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.events.MapAdminEventEntity> delegateProvider;
    public MapAdminEventEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.events.MapAdminEventEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.ID, id).setId(id);
    }
    @Override public Long getExpiration() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.EXPIRATION).getExpiration();
    }
    @Override public void setExpiration(Long expiration) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.EXPIRATION, expiration).setExpiration(expiration);
    }
    @Override public Long getTimestamp() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.TIMESTAMP).getTimestamp();
    }
    @Override public void setTimestamp(Long timestamp) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.TIMESTAMP, timestamp).setTimestamp(timestamp);
    }
    @Override public String getRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.REALM_ID).getRealmId();
    }
    @Override public void setRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.REALM_ID, realmId).setRealmId(realmId);
    }
    @Override public org.keycloak.events.admin.OperationType getOperationType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.OPERATION_TYPE).getOperationType();
    }
    @Override public void setOperationType(org.keycloak.events.admin.OperationType operationType) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.OPERATION_TYPE, operationType).setOperationType(operationType);
    }
    @Override public String getResourcePath() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_PATH).getResourcePath();
    }
    @Override public void setResourcePath(String resourcePath) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_PATH, resourcePath).setResourcePath(resourcePath);
    }
    @Override public String getRepresentation() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.REPRESENTATION).getRepresentation();
    }
    @Override public void setRepresentation(String representation) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.REPRESENTATION, representation).setRepresentation(representation);
    }
    @Override public String getError() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.ERROR).getError();
    }
    @Override public void setError(String error) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.ERROR, error).setError(error);
    }
    @Override public String getResourceType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_TYPE).getResourceType();
    }
    @Override public void setResourceType(String resourceType) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_TYPE, resourceType).setResourceType(resourceType);
    }
    @Override public String getAuthRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_REALM_ID).getAuthRealmId();
    }
    @Override public void setAuthRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_REALM_ID, realmId).setAuthRealmId(realmId);
    }
    @Override public String getAuthClientId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_CLIENT_ID).getAuthClientId();
    }
    @Override public void setAuthClientId(String clientId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_CLIENT_ID, clientId).setAuthClientId(clientId);
    }
    @Override public String getAuthUserId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_USER_ID).getAuthUserId();
    }
    @Override public void setAuthUserId(String userId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_USER_ID, userId).setAuthUserId(userId);
    }
    @Override public String getAuthIpAddress() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_IP_ADDRESS).getAuthIpAddress();
    }
    @Override public void setAuthIpAddress(String ipAddress) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_IP_ADDRESS, ipAddress).setAuthIpAddress(ipAddress);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/events/MapAdminEventEntityDelegate.java <==
package org.keycloak.models.map.events;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAdminEventEntityDelegate implements org.keycloak.models.map.events.MapAdminEventEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.events.MapAdminEventEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.events.MapAdminEventEntity> delegateProvider;
    public MapAdminEventEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.events.MapAdminEventEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.events.MapAdminEventEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.ID, id).setId(id);
    }
    @Override public Long getExpiration() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.EXPIRATION).getExpiration();
    }
    @Override public void setExpiration(Long expiration) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.EXPIRATION, expiration).setExpiration(expiration);
    }
    @Override public Long getTimestamp() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.TIMESTAMP).getTimestamp();
    }
    @Override public void setTimestamp(Long timestamp) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.TIMESTAMP, timestamp).setTimestamp(timestamp);
    }
    @Override public String getRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.REALM_ID).getRealmId();
    }
    @Override public void setRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.REALM_ID, realmId).setRealmId(realmId);
    }
    @Override public org.keycloak.events.admin.OperationType getOperationType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.OPERATION_TYPE).getOperationType();
    }
    @Override public void setOperationType(org.keycloak.events.admin.OperationType operationType) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.OPERATION_TYPE, operationType).setOperationType(operationType);
    }
    @Override public String getResourcePath() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_PATH).getResourcePath();
    }
    @Override public void setResourcePath(String resourcePath) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_PATH, resourcePath).setResourcePath(resourcePath);
    }
    @Override public String getRepresentation() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.REPRESENTATION).getRepresentation();
    }
    @Override public void setRepresentation(String representation) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.REPRESENTATION, representation).setRepresentation(representation);
    }
    @Override public String getError() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.ERROR).getError();
    }
    @Override public void setError(String error) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.ERROR, error).setError(error);
    }
    @Override public String getResourceType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_TYPE).getResourceType();
    }
    @Override public void setResourceType(String resourceType) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_TYPE, resourceType).setResourceType(resourceType);
    }
    @Override public String getAuthRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_REALM_ID).getAuthRealmId();
    }
    @Override public void setAuthRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_REALM_ID, realmId).setAuthRealmId(realmId);
    }
    @Override public String getAuthClientId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_CLIENT_ID).getAuthClientId();
    }
    @Override public void setAuthClientId(String clientId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_CLIENT_ID, clientId).setAuthClientId(clientId);
    }
    @Override public String getAuthUserId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_USER_ID).getAuthUserId();
    }
    @Override public void setAuthUserId(String userId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_USER_ID, userId).setAuthUserId(userId);
    }
    @Override public String getAuthIpAddress() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_IP_ADDRESS).getAuthIpAddress();
    }
    @Override public void setAuthIpAddress(String ipAddress) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_IP_ADDRESS, ipAddress).setAuthIpAddress(ipAddress);
    }
}
